<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Simon <sbx@protonmail.ch>
 * @author Jaka Kranjc <lynxlupodian@hotmail.com>
 * @author Boštjan Seničar <senicar@gmail.com>
 * @author Dejan Levec <webphp@gmail.com>
 * @author Gregor Skumavc (grega.skumavc@gmail.com)
 * @author Matej Urbančič (mateju@svn.gnome.org)
 * @author Matej Urbančič <mateju@svn.gnome.org>
 * @author Jernej Vidmar <jernej.vidmar@vidmarboehm.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Uredi stran';
$lang['btn_source']            = 'Pokaži izvorno kodo strani';
$lang['btn_show']              = 'Pokaži stran';
$lang['btn_create']            = 'Ustvari stran';
$lang['btn_search']            = 'Poišči';
$lang['btn_save']              = 'Shrani';
$lang['btn_preview']           = 'Predogled';
$lang['btn_top']               = 'Nazaj na vrh';
$lang['btn_newer']             = '<< novejši';
$lang['btn_older']             = 'starejši >>';
$lang['btn_revs']              = 'Stare različice';
$lang['btn_recent']            = 'Nedavne spremembe';
$lang['btn_upload']            = 'Pošlji';
$lang['btn_cancel']            = 'Prekliči';
$lang['btn_index']             = 'Kazalo';
$lang['btn_secedit']           = 'Uredi';
$lang['btn_login']             = 'Prijava';
$lang['btn_logout']            = 'Odjava';
$lang['btn_admin']             = 'Skrbništvo';
$lang['btn_update']            = 'Posodobi';
$lang['btn_delete']            = 'Izbriši';
$lang['btn_back']              = 'Nazaj';
$lang['btn_backlink']          = 'Povratne povezave';
$lang['btn_subscribe']         = 'Urejanje naročnin';
$lang['btn_profile']           = 'Posodobi profil';
$lang['btn_reset']             = 'Ponastavi';
$lang['btn_resendpwd']         = 'Nastavi novo geslo';
$lang['btn_draft']             = 'Uredi osnutek';
$lang['btn_recover']           = 'Obnovi osnutek';
$lang['btn_draftdel']          = 'Izbriši osnutek';
$lang['btn_revert']            = 'Povrni';
$lang['btn_register']          = 'Registracija';
$lang['btn_apply']             = 'Uveljavi';
$lang['btn_media']             = 'Urejevalnik predstavnih vsebin';
$lang['btn_deleteuser']        = 'Odstrani račun';
$lang['btn_img_backto']        = 'Nazaj na %s';
$lang['btn_mediaManager']      = 'Poglej v urejevalniku predstavnih vsebin';
$lang['loggedinas']            = 'Prijava kot:';
$lang['user']                  = 'Uporabniško ime';
$lang['pass']                  = 'Geslo';
$lang['newpass']               = 'Novo geslo';
$lang['oldpass']               = 'Potrdi trenutno geslo';
$lang['passchk']               = 'Ponovi novo geslo';
$lang['remember']              = 'Zapomni si me';
$lang['fullname']              = 'Pravo ime';
$lang['email']                 = 'Elektronski naslov';
$lang['profile']               = 'Uporabniški profil';
$lang['badlogin']              = 'Uporabniško ime ali geslo je napačno.';
$lang['badpassconfirm']        = 'Napaka! Geslo ni pravo.';
$lang['minoredit']             = 'Manjše spremembe';
$lang['draftdate']             = 'Samodejno shranjevanje osnutka je omogočeno';
$lang['nosecedit']             = 'Stran je bila v vmesnem času spremenjena. Podatki strani so bili zastareli, zato se je celotna vsebina naložila znova.';
$lang['regmissing']            = 'Izpolniti je treba vsa polja.';
$lang['reguexists']            = 'Uporabnik s tem imenom že obstaja.';
$lang['regsuccess']            = 'Uporabniški račun je uspešno ustvarjen. Geslo je bilo poslano na naveden elektronski naslov.';
$lang['regsuccess2']           = 'Uporabniški račun je uspešno ustvarjen.';
$lang['regmailfail']           = 'Videti je, da je prišlo do napake med pošiljanjem gesla. Stopite v stik s skrbnikom sistema!';
$lang['regbadmail']            = 'Videti je, da je naveden elektronski naslov neveljaven - v kolikor je to napaka, stopite v stik s skrbnikom sistema.';
$lang['regbadpass']            = 'Gesli nista enaki. Poskusite znova.';
$lang['regpwmail']             = 'Geslo za DokuWiki';
$lang['reghere']               = 'Nimate še računa? Vpišite se za nov račun.';
$lang['profna']                = 'DokuWiki ne podpira spreminjanja profila.';
$lang['profnochange']          = 'Brez sprememb.';
$lang['profnoempty']           = 'Prazno polje elektronskega naslova ali imena ni dovoljeno.';
$lang['profchanged']           = 'Uporabniški profil je uspešno posodobljen.';
$lang['profnodelete']          = 'Ni omogočena podpora za brisanje uporabnikov.';
$lang['profdeleteuser']        = 'Izbriši račun';
$lang['profdeleted']           = 'Uporabniški račun je izbrisan.';
$lang['profconfdeletemissing'] = 'Potrditveno okno ni označeno';
$lang['pwdforget']             = 'Ali ste pozabili geslo? Pridobite si novo geslo.';
$lang['resendna']              = 'DokuWiki ne podpira možnosti ponovnega pošiljanja gesel.';
$lang['resendpwd']             = 'Nastavi novo geslo za';
$lang['resendpwdmissing']      = 'Izpolniti je treba vsa polja.';
$lang['resendpwdnouser']       = 'Podanega uporabniškega imena v podatkovni zbirki ni mogoče najti.';
$lang['resendpwdbadauth']      = 'Koda za overitev ni prava. Prepričajte se, da ste uporabili celotno povezavo za potrditev.';
$lang['resendpwdconfirm']      = 'Povezava za potrditev računa je bila poslana na elektronski naslov.';
$lang['resendpwdsuccess']      = 'Novo geslo je bilo poslano na elektronski naslov.';
$lang['license']               = 'V kolikor ni posebej določeno, je vsebina Wiki strani objavljena pod pogoji dovoljenja:';
$lang['licenseok']             = 'Opomba: z urejanjem vsebine strani, se strinjate z objavo pod pogoji dovoljenja:';
$lang['searchmedia']           = 'Poišči ime datoteke:';
$lang['searchmedia_in']        = 'Poišči v %s';
$lang['txt_upload']            = 'Izberite datoteko za pošiljanje:';
$lang['txt_filename']          = 'Pošlji z imenom (izborno):';
$lang['txt_overwrt']           = 'Prepiši obstoječo datoteko';
$lang['lockedby']              = 'Trenutno je zaklenjeno s strani:';
$lang['lockexpire']            = 'Zaklep preteče ob:';
$lang['js']['willexpire']      = 'Zaklep za urejevanje bo pretekel čez eno minuto.\nV izogib sporom, uporabite predogled, da se merilnik časa za zaklep ponastavi.';
$lang['js']['notsavedyet']     = 'Neshranjene spremembe bodo izgubljene.';
$lang['js']['searchmedia']     = 'Poišči datoteke';
$lang['js']['keepopen']        = 'Od izbiri ohrani okno odprto';
$lang['js']['hidedetails']     = 'Skrij podrobnosti';
$lang['js']['mediatitle']      = 'Nastavitve povezave';
$lang['js']['mediadisplay']    = 'Vrsta povezave';
$lang['js']['mediaalign']      = 'Poravnava';
$lang['js']['mediasize']       = 'Velikost slike';
$lang['js']['mediatarget']     = 'Mesto povezave';
$lang['js']['mediaclose']      = 'Zapri';
$lang['js']['mediainsert']     = 'Vstavi';
$lang['js']['mediadisplayimg'] = 'Pokaži sliko.';
$lang['js']['mediadisplaylnk'] = 'Pokaži le povezavo.';
$lang['js']['mediasmall']      = 'Majhna različica';
$lang['js']['mediamedium']     = 'Srednja različica';
$lang['js']['medialarge']      = 'Velika različica';
$lang['js']['mediaoriginal']   = 'Izvorna različica';
$lang['js']['medialnk']        = 'Povezava na strani podrobnosti';
$lang['js']['mediadirect']     = 'Neposredna povezava do izvorne različice';
$lang['js']['medianolnk']      = 'Brez povezave';
$lang['js']['medianolink']     = 'Ne poveži s sliko';
$lang['js']['medialeft']       = 'Poravnaj sliko na levo.';
$lang['js']['mediaright']      = 'Poravnaj sliko na desno.';
$lang['js']['mediacenter']     = 'Poravnaj sliko na sredini.';
$lang['js']['medianoalign']    = 'Ne uporabi poravnave.';
$lang['js']['nosmblinks']      = 'Povezovanje do souporabnih datotek sistema Windows deluje le pri uporabi brskalnika Microsoft Internet Explorer. Povezavo je mogoče kopirati ročno.';
$lang['js']['linkwiz']         = 'Čarovnik za povezave';
$lang['js']['linkto']          = 'Poveži na:';
$lang['js']['del_confirm']     = 'Ali naj se res izbrišejo izbrani predmeti?';
$lang['js']['restore_confirm'] = 'Ali naj se koda obnovi na to različico?';
$lang['js']['media_diff']      = 'Razlike:';
$lang['js']['media_diff_both'] = 'Eno ob drugem';
$lang['js']['media_diff_opacity'] = 'Prosojno';
$lang['js']['media_select']    = 'Izbor datotek ...';
$lang['js']['media_upload_btn'] = 'Naloži';
$lang['js']['media_done_btn']  = 'Končano';
$lang['js']['media_drop']      = 'Spusti datoteke za nalaganje.';
$lang['js']['media_cancel']    = 'odstrani';
$lang['js']['media_overwrt']   = 'Prepiši obstoječe datoteke';
$lang['rssfailed']             = 'Prišlo je do napake med pridobivanjem vira: ';
$lang['nothingfound']          = 'Ni najdenih predmetov.';
$lang['mediaselect']           = 'Predstavne datoteke';
$lang['uploadsucc']            = 'Pošiljanje je bilo uspešno končano.';
$lang['uploadfail']            = 'Pošiljanje je spodletelo. Morda so uporabljena neustrezna dovoljenja.';
$lang['uploadwrong']           = 'Pošiljanje je zavrnjeno. Uporabljena pripona datoteke je prepovedana.';
$lang['uploadexist']           = 'Datoteka že obstaja. Ni sprememb.';
$lang['uploadbadcontent']      = 'Poslana datoteka se ne sklada s pripono (%s) datoteke.';
$lang['uploadspam']            = 'Pošiljanje je bilo ustavljeno na podlagi zapisa na črnem seznamu neželenih datotek.';
$lang['uploadxss']             = 'Pošiljanje je zaustavljeno zaradi morebitne zlonamerne vsebine.';
$lang['uploadsize']            = 'poslana datoteka prevelika (največja dovoljena velikost je %s).';
$lang['deletesucc']            = 'Datoteka "%s" je izbrisana.';
$lang['deletefail']            = 'Datoteke "%s" ni mogoče izbrisati - preverite uporabniška dovoljenja.';
$lang['mediainuse']            = 'Datoteka "%s" ni izbrisana - datoteka je še vedno v uporabi.';
$lang['namespaces']            = 'Imenski prostori';
$lang['mediafiles']            = 'Datoteke, ki so na voljo v';
$lang['accessdenied']          = 'Za ogled te strani so zahtevana posebna dovoljenja.';
$lang['mediausage']            = 'Za navajanje datoteke je treba uporabiti navedeno skladnjo:';
$lang['mediaview']             = 'Pogled izvorne datoteke';
$lang['mediaroot']             = 'koren';
$lang['mediaupload']           = 'Pošiljanje datoteke v trenutni imenski prostor. Za ustvarjanje novih imenskih prostorov, jih pripnite k imenu datoteke navedene pri vnosnem polju "Naloži kot" in jih ločite z dvopičjem.';
$lang['mediaextchange']        = 'Pripona datoteke je spremenjena iz .%s v .%s!';
$lang['reference']             = 'Sklic za';
$lang['ref_inuse']             = 'Datoteke ni mogoče izbrisati, saj je še vedno povezana s stranmi:';
$lang['ref_hidden']            = 'Nekaj sklicev je navedenih na straneh, do katerih s trenutnimi dovoljenji ni mogoč dostop.';
$lang['hits']                  = 'Zadetki';
$lang['quickhits']             = 'Ujemanje imen strani';
$lang['toc']                   = 'Kazalo';
$lang['current']               = 'Trenutna';
$lang['yours']                 = 'Vaša različica';
$lang['diff']                  = 'Pokaži razlike s trenutno različico';
$lang['diff2']                 = 'Pokaži razlike med izbranimi različicami.';
$lang['difflink']              = 'Poveži s tem pogledom primerjave.';
$lang['diff_type']             = 'Razlike:';
$lang['diff_inline']           = 'V besedilu';
$lang['diff_side']             = 'Eno ob drugem';
$lang['diffprevrev']           = 'Prejšnja revizija';
$lang['diffnextrev']           = 'Naslednja revizija';
$lang['difflastrev']           = 'Zadnja revizija';
$lang['line']                  = 'Vrstica';
$lang['breadcrumb']            = 'Sled:';
$lang['youarehere']            = 'Trenutno dejavna stran:';
$lang['lastmod']               = 'Zadnja sprememba:';
$lang['by']                    = 'uporabnika';
$lang['deleted']               = 'odstranjena';
$lang['created']               = 'ustvarjena';
$lang['restored']              = 'povrnjena stara različica (%s)';
$lang['external_edit']         = 'urejanje v zunanjem urejevalniku';
$lang['summary']               = 'Povzetek urejanja';
$lang['noflash']               = 'Za prikaz vsebine je treba namestiti <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
$lang['download']              = 'Naloži izrezek';
$lang['tools']                 = 'Orodja';
$lang['user_tools']            = 'Uporabniška orodja';
$lang['site_tools']            = 'Orodja spletišča';
$lang['page_tools']            = 'Orodja strani';
$lang['skip_to_content']       = 'preskoči na vsebino';
$lang['sidebar']               = 'Stranska vrstica';
$lang['mail_newpage']          = '[DokuWiki] stran dodana:';
$lang['mail_changed']          = '[DokuWiki] stran spremenjena:';
$lang['mail_subscribe_list']   = 'strani s spremenjenim imenom:';
$lang['mail_new_user']         = 'nov uporabnik:';
$lang['mail_upload']           = 'naložena datoteka:';
$lang['changes_type']          = 'Poglej spremembe';
$lang['pages_changes']         = 'Strani';
$lang['media_changes']         = 'Predstavne datoteke';
$lang['both_changes']          = 'Strani in predstavne datoteke';
$lang['qb_bold']               = 'Krepko besedilo';
$lang['qb_italic']             = 'Ležeče besedilo';
$lang['qb_underl']             = 'Podčrtano besedilo';
$lang['qb_code']               = 'Oznaka kode';
$lang['qb_strike']             = 'Prečrtano besedilo';
$lang['qb_h1']                 = 'Naslov prve ravni';
$lang['qb_h2']                 = 'Naslov druge ravni';
$lang['qb_h3']                 = 'Naslov tretje ravni';
$lang['qb_h4']                 = 'Naslov četrte ravni';
$lang['qb_h5']                 = 'Naslov pete ravni';
$lang['qb_h']                  = 'Naslov';
$lang['qb_hs']                 = 'Izberi naslov';
$lang['qb_hplus']              = 'Naslov na višji ravni';
$lang['qb_hminus']             = 'Naslov na nižji ravni';
$lang['qb_hequal']             = 'Naslov na isti ravni';
$lang['qb_link']               = 'Notranja povezava';
$lang['qb_extlink']            = 'Zunanja povezava';
$lang['qb_hr']                 = 'Vodoravna črta';
$lang['qb_ol']                 = 'Številčna oznaka predmeta';
$lang['qb_ul']                 = 'Vrstična oznaka predmeta';
$lang['qb_media']              = 'Dodajanje slik in drugih datotek';
$lang['qb_sig']                = 'Vstavi podpis';
$lang['qb_smileys']            = 'Smeški';
$lang['qb_chars']              = 'Posebni znaki';
$lang['upperns']               = 'skoči na nadrejeni imenski prostor';
$lang['metaedit']              = 'Uredi metapodatke';
$lang['metasaveerr']           = 'Zapisovanje metapodatkov je spodletelo';
$lang['metasaveok']            = 'Metapodatki so shranjeni';
$lang['img_title']             = 'Naslov:';
$lang['img_caption']           = 'Opis:';
$lang['img_date']              = 'Datum:';
$lang['img_fname']             = 'Ime datoteke:';
$lang['img_fsize']             = 'Velikost:';
$lang['img_artist']            = 'Fotograf:';
$lang['img_copyr']             = 'Avtorska pravica:';
$lang['img_format']            = 'Zapis:';
$lang['img_camera']            = 'Fotoaparat:';
$lang['img_keywords']          = 'Ključne besede:';
$lang['img_width']             = 'Širina:';
$lang['img_height']            = 'Višina:';
$lang['subscr_subscribe_success'] = 'Uporabniški račun %s je dodan na seznam naročnin na %s';
$lang['subscr_subscribe_error'] = 'Napaka med dodajanjem %s na seznam naročnin na %s';
$lang['subscr_subscribe_noaddress'] = 'S trenutnimi prijavnimi podatki ni povezanega elektronskega naslova, zato uporabniškega računa ni mogoče dodati na seznam naročnikov.';
$lang['subscr_unsubscribe_success'] = 'Uporabniški račun %s je odstranjen s seznama naročnin na %s';
$lang['subscr_unsubscribe_error'] = 'Napaka med odstranjevanjem %s s seznama naročnin na %s';
$lang['subscr_already_subscribed'] = '%s je že naročen na %s';
$lang['subscr_not_subscribed'] = '%s ni naročen na %s';
$lang['subscr_m_not_subscribed'] = 'Trenutni uporabniški račun nima prijavljene naročnine na trenutno stran ali imenski prostor.';
$lang['subscr_m_new_header']   = 'Naročanje';
$lang['subscr_m_current_header'] = 'Trenutne naročnine';
$lang['subscr_m_unsubscribe']  = 'Prekliči naročnino';
$lang['subscr_m_subscribe']    = 'Prijavi naročnino';
$lang['subscr_m_receive']      = 'Prejmi';
$lang['subscr_style_every']    = 'elektronsko sporočilo ob vsaki spremembi';
$lang['subscr_style_digest']   = 'strnjeno elektronsko sporočilo sprememb za vsako stran (vsakih %.2f dni)';
$lang['subscr_style_list']     = 'seznam spremenjenih strani od zadnjega elektronskega sporočila (vsakih %.2f dni)';
$lang['authtempfail']          = 'Potrditev uporabnika je trenutno nedostopna. Stopite v stik s skrbnikom sistema wiki.';
$lang['i_chooselang']          = 'Izberite jezik';
$lang['i_installer']           = 'DokuWiki namestitev';
$lang['i_wikiname']            = 'Ime Wiki spletišča';
$lang['i_enableacl']           = 'Omogoči ACL (priporočeno)';
$lang['i_superuser']           = 'Skrbnik';
$lang['i_problems']            = 'Namestilnik je naletel na težave, ki so izpisane spodaj. Namestitve ni mogoče nadaljevati, dokler težave ne bodo odpravljene.';
$lang['i_modified']            = 'Iz varnostnih razlogov skript deluje le v novi in neprilagojeni namestitvi sistema DokuWiki. Postopek namestitve je treba začeti znova ali pa sistem namestiti ročno s pomočjo <a href="http://dokuwiki.org/install">navodil nameščanja Dokuwiki</a>.';
$lang['i_funcna']              = 'Funkcija PHP <code>%s</code> ni na voljo. Morda je možnost na strežniku zaradi varnostnih razlogov onemogočena.';
$lang['i_phpver']              = 'Različica PHP <code>%s</code> je nižja od zahtevane različice <code>%s</code>. Pred nadaljevanjem je treba posodobiti namestitev PHP.';
$lang['i_permfail']            = 'Predmet <code>%s</code> ni zapisljiv. Zahtevana je sprememba dovoljenj za to mapo.';
$lang['i_confexists']          = 'Predmet <code>%s</code> že obstaja.';
$lang['i_writeerr']            = 'Ni mogoče ustvariti predmeta <code>%s</code>. Preveriti je treba dovoljenja datotek in map in nato ustvariti datoteko ročno.';
$lang['i_badhash']             = 'nepoznana ali spremenjena datoteka dokuwiki.php (razpršilo=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - neveljavna ali prazna vrednost';
$lang['i_success']             = 'Nastavitev je uspešno končana. Datoteko install.php lahko sedaj izbrišete. Nadaljujte v <a href="doku.php?id=wiki:welcome">novi DokuWiki</a>.';
$lang['i_failure']             = 'Med zapisovanjem nastavitvenih datotek je prišlo do napak. Preden lahko uporabite vaš <a href="doku.php?id=wiki:welcome">DokuWiki</a>, jih je treba odpraviti.';
$lang['i_policy']              = 'Začetna določila ACL';
$lang['i_pol0']                = 'Odprt Wiki (branje, zapis, nalaganje datotek je javno za vse)';
$lang['i_pol1']                = 'Javni Wiki (branje za vse, zapis in nalaganje datotek za prijavljene uporabnike)';
$lang['i_pol2']                = 'Zaprt Wiki (berejo in urejajo lahko le prijavljeni uporabniki)';
$lang['i_allowreg']            = 'Dovoli uporabnikom vpis';
$lang['i_retry']               = 'Ponovni poskus';
$lang['i_license']             = 'Izbor dovoljenja objave vsebine:';
$lang['i_license_none']        = 'Ne pokaži podrobnosti dovoljenja.';
$lang['i_pop_field']           = 'Prosimo pomagajte nam izboljšati DokuWiki izkušnjo:';
$lang['i_pop_label']           = 'Enkrat na mesec pošlji anonimne uporabniške podatke DokuWiki razvijalcem';
$lang['recent_global']         = 'Trenutno so prikazane spremembe znotraj imenskega prostora <b>%s</b>. Mogoče si je ogledati tudi spremembe <a href="%s">celotnega sistema Wiki</a>.';
$lang['years']                 = '%d let nazaj';
$lang['months']                = '%d mesecev nazaj';
$lang['weeks']                 = '%d tednov nazaj';
$lang['days']                  = '%d dni nazaj';
$lang['hours']                 = '%d ur nazaj';
$lang['minutes']               = '%d minut nazaj';
$lang['seconds']               = '%d sekund nazaj';
$lang['wordblock']             = 'Spremembe niso shranjene, ker je v vsebini navedeno neželeno besedilo (spam).';
$lang['media_uploadtab']       = 'Naloži';
$lang['media_searchtab']       = 'Poišči';
$lang['media_file']            = 'Datoteka';
$lang['media_viewtab']         = 'Pogled';
$lang['media_edittab']         = 'Uredi';
$lang['media_historytab']      = 'Zgodovina';
$lang['media_list_thumbs']     = 'Sličice';
$lang['media_list_rows']       = 'Vrstice';
$lang['media_sort_name']       = 'Ime';
$lang['media_sort_date']       = 'Datum';
$lang['media_namespaces']      = 'Izbor imenskega prostora';
$lang['media_files']           = 'Datoteke v %s';
$lang['media_upload']          = 'Naloži v %s';
$lang['media_search']          = 'Poišči v %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s pri %s';
$lang['media_edit']            = 'Uredi %s';
$lang['media_history']         = 'Zgodovina %s';
$lang['media_meta_edited']     = 'metapodatki so urejeni';
$lang['media_perm_read']       = 'Ni ustreznih dovoljenj za branje datotek.';
$lang['media_perm_upload']     = 'Ni ustreznih dovoljenj za nalaganje datotek.';
$lang['media_update']          = 'Naloži novo različico';
$lang['media_restore']         = 'Obnovi to različico';
$lang['currentns']             = 'Trenutni imenski prostor';
$lang['searchresult']          = 'Rezultati iskanja';
$lang['plainhtml']             = 'Zapis HTML';
$lang['wikimarkup']            = 'Oblikovni jezik Wiki';
$lang['email_signature_text']  = 'Sporočilo je samodejno ustvarjeno na spletišču
@DOKUWIKIURL@';
